import React, { useEffect, useMemo, useState } from 'react'
import { Select, Input, message, Modal, Spin, Checkbox, Row, Col, Radio } from 'antd'
import { UserAddOutlined } from '@ant-design/icons'
import styles from '../index.less'
import { getMenTreeByRole, getUserListForRole } from '../../../../../apis/process'

const UserGroup = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { value, onChange, schema, addons } = props
  const { disabled, isMultiple, placeholder, presetValue, role, isStoreID } = schema
  const [groupPerson, setGroupPerson] = useState([])
  const [visible, setVisible] = useState(false)
  const [loading, setLoading] = useState(false)
  const [check, setCheck] = useState([])
  const [radio, setRadio] = useState(null)
  const [search, setSearch] = useState(null)

  const groupPersonShow = useMemo(() => {
    if (search) {
      let array = []
      groupPerson.forEach(v => {
        let userList = []
        let noShowParent = !v.ouName.includes(search)
        console.log(noShowParent, v.ouName, search)
        v.userList.forEach(s => {
          let noShow = !s.userName.includes(search)
          if (!noShow) {
            noShowParent = false
          }
          userList.push({ ...s, noShow: !noShowParent ? noShowParent : noShow })
        })
        array.push({ ...v, userList, noShow: noShowParent })
      })
      return array
    }
    return groupPerson
  }, [search, groupPerson])

  const onOk = () => {
    if (addons) {
      addons.setValue(addons.dataPath, isMultiple ? check.join(',') : radio)
    }
    setVisible(false)
  }

  const inputChange = (value) => {
    setSearch(value)
  }

  const checkChange = (value) => {
    setCheck(value)
  }

  const radioChange = (e) => {
    setRadio(e.target.value)
  }

  const checkGroup = (v, type) => {
    let array = v.userList.map(v => v.userName)
    if (type === 'true') {
      setCheck(check.filter(v => !array.includes(v)))
    } else {
      setCheck(Array.from(new Set([...check, ...array])))
    }
  }

  const getGorupType = (v, checkCount) => {
    if (checkCount === 0) {
      return 'false'
    } else if (v.userList.length === checkCount) {
      return 'true'
    }
    return 'other'
  }

  const inputFocus = async () => {
    if (addons) {
      setVisible(true)
      setLoading(true)
      const { code, data, msg } = await getUserListForRole({})
      if (code === 0) {
        if (Array.isArray(data)) {
          setGroupPerson(data)
        }
      } else {
        message.error(msg)
      }
      setLoading(false)
    }
  }

  const getCount = (v) => {
    let array = v.userList.filter(s => check.includes(s.userName))
    if (Array.isArray(array)) {
      return array.length
    }
    return 0
  }

  useEffect(() => {
    if (isMultiple) {
      setCheck(value ? value.split(',') : [])
    } else {
      setRadio(value)
    }
  }, [isMultiple, value])

  return (
    <div className={styles.personGroup}>
      <Input
        disabled={disabled}
        value={isMultiple ? (value ? value.split(',') : []) : value}
        placeholder={disabled ? null : placeholder}
        onClick={inputFocus}
        addonAfter={disabled ? null : <UserAddOutlined style={{ color: 'rgba(0, 0, 0, 0.25)' }} onClick={inputFocus} />}
        style={{ width: '100%' }}
      />
      <Modal
        title='人员选择器'
        visible={visible}
        bodyStyle={{ height: 450 }}
        onCancel={() => setVisible(false)}
        onOk={onOk}
        getContainer={false}
      >
        <Spin
          spinning={loading}
        >
          <Input.Search
            placeholder='请输入姓名'
            allowClear
            enterButton
            value={search}
            onChange={(e) => inputChange(e.target.value)}
          />
          {
            isMultiple ?
              <Checkbox.Group
                style={{ width: '100%', height: '400px', overflow: 'auto', marginTop: '10px' }}
                value={check}
                onChange={checkChange}
              >
                {
                  groupPersonShow.map(v => {
                    let checkCount = getCount(v)
                    let type = getGorupType(v, checkCount)
                    return (
                      <div className={styles.groupUser} style={{ display: v.noShow ? 'none' : 'block' }}>
                        <div className={styles.groupName} onClick={() => checkGroup(v, type)}>
                          <span className={styles.groupCheck} type={type}></span>
                          <span>{v.ouName + `${checkCount}/${v.userList.length}`}</span>
                        </div>
                        <Row style={{ paddingLeft: '40px' }}>
                          {
                            v.userList.map(s => {
                              return (
                                <Col span={8} key={s.userID} style={{ margin: '8px 0', display: s.noShow ? 'none' : 'block' }}>
                                  <Checkbox
                                    value={s.userName}
                                  >
                                    <div>{s.userName}</div>
                                  </Checkbox>
                                </Col>
                              )
                            })
                          }
                        </Row>
                      </div>
                    )
                  })
                }
              </Checkbox.Group>
              :
              <Radio.Group
                value={radio}
                onChange={radioChange}
                style={{ width: '100%', height: '400px', overflow: 'auto', marginTop: '10px' }}
              >
                {
                  groupPersonShow.map(v => {
                    let checkCount = getCount(v)
                    let type = getGorupType(v, checkCount)
                    return (
                      <div className={styles.groupUser} style={{ display: v.noShow ? 'none' : 'block' }} key={v.ouid}>
                        <div className={styles.groupName}>
                          <span style={{ fontSize: '14px', fontWeight: 'bold' }}>{v.ouName}</span>
                        </div>
                        <Row style={{ paddingLeft: '40px' }}>
                          {
                            v.userList.map(s => {
                              return (
                                <Col span={8} style={{ margin: '8px 0', display: s.noShow ? 'none' : 'block' }} key={s.userID}>
                                  <Radio
                                    value={s.userName}
                                  >
                                    <div>{s.userName}</div>
                                  </Radio>
                                </Col>
                              )
                            })
                          }
                        </Row>
                      </div>
                    )
                  })
                }
              </Radio.Group>
          }
        </Spin>
      </Modal>
    </div>
  )

}

export default UserGroup