import React, { useEffect, useMemo, useState } from 'react'
import { Select, Input, message, Modal, Spin, Checkbox, Row, Col, Radio } from 'antd'
import { UserAddOutlined } from '@ant-design/icons'
import { getMenTreeByRole, getUserListForRole } from '../../../../../apis/process'

const UserSelect = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { value, onChange, schema, addons } = props
  const { disabled, isMultiple, placeholder, role, isStoreID } = schema
  const [pullDown, setPullDown] = useState([])

  const selectFocus = async () => {
    if (!role) {
      return message.error('请配置机构角色!')
    }
    const { code, data, msg } = await getMenTreeByRole({ userID, role: role })
    if (code === 0) {
      if (data && data.childNodes) {
        setPullDown(data.childNodes)
      } else {
        setPullDown([])
      }
    } else {
      message.info(msg)
    }
  }

  const selectChange = (value) => {
    if (addons) {
      onChange(isMultiple ? value.join(',') : value)
    }
  }

  return (
    <Select
      mode={isMultiple ? 'multiple' : null}
      placeholder={disabled ? null : placeholder}
      value={isMultiple ? (value ? value.split(',') : []) : value}
      disabled={disabled}
      showArrow={!disabled}
      showSearch={true}
      style={{ width: '100%' }}
      onFocus={selectFocus}
      onChange={selectChange}
    >
      {pullDown.map(v => <Select.Option key={v.value} value={v.value}>{v.text}</Select.Option>)}
    </Select>
  )

}

export default UserSelect