import React, { useEffect, useMemo, useState } from 'react'
import { Input, Modal, Tree, message, Table } from 'antd'
import { UserAddOutlined, DownOutlined } from '@ant-design/icons'
import { getUserSelector } from '../../../../../apis/process'
import styles from '../index.less'

const columns = [
  {
    title: '序号',
    render: (r, t, i) => i + 1
  },
  {
    title: '用户名',
    dataIndex: 'loginName',
    key: 'loginName',
  },
  {
    title: '用户名',
    dataIndex: 'userName',
    key: 'userName',
  }
]

const getUserList = (treeData, treeKey) => {
  let array = []
  if (Array.isArray(treeData)) {
    treeData.forEach(v => {
      if (v.ouCode === treeKey[0]) {
        if (Array.isArray(v.userList)) {
          array.push(...v.userList)
        }
      }
      array.push(...getUserList(v.children, treeKey))
    })
  }
  return array
}

const getSelectUser = (treeData, selectKeys, property) => {
  let array = []
  if (Array.isArray(treeData)) {
    treeData.forEach(v => {
      if (Array.isArray(v.userList)) {
        v.userList.forEach(s => {
          if (selectKeys.includes(s[property])) {
            array.push(s)
          }
        })
      }
      // if (v.ouCode === treeKey[0]) {
      //   if (Array.isArray(v.userList)) {
      //     array.push(...v.userList)
      //   }
      // }
      array.push(...getSelectUser(v.children, selectKeys, property))
    })
  }
  return array
}

const UserTree = (props) => {

  const userID = window?.globalConfig?.userInfo?.OID || 1
  const { value, onChange, schema, addons } = props
  const { disabled, isMultiple, placeholder, presetValue, role, isStoreID } = schema
  const property = isStoreID ? 'userID' : 'userName'
  const [visible, setVisible] = useState(false)
  const [treeData, setTreeData] = useState([])
  const [treeKey, setTreeKey] = useState([])
  const [users, setUsers] = useState([])

  const userList = useMemo(() => {
    return getUserList(treeData, treeKey)
  }, [treeData, treeKey])

  const selectKeys = useMemo(() => {
    return value ? value.split(',') : []
  }, [value, property])

  const selectUser = useMemo(() => {
    return getSelectUser(treeData, selectKeys, property)
  }, [treeData, selectKeys, property])

  const inputFocus = async () => {
    setVisible(true)
    const { code, data, msg } = await getUserSelector()
    if (code === 0) {
      setTreeData(data.treeList)
    } else {
      message.error(msg)
    }
  }

  const onOk = () => {

  }

  const treeChange = (value) => {
    setTreeKey(value)
  }

  return (
    <div className={styles.userTree}>
      <Input
        disabled={disabled}
        value={isMultiple ? (value ? value.split(',') : []) : value}
        placeholder={disabled ? null : placeholder}
        onClick={inputFocus}
        addonAfter={disabled ? null : <UserAddOutlined style={{ color: 'rgba(0, 0, 0, 0.25)' }} onClick={inputFocus} />}
        style={{ width: '100%' }}
      />
      <Modal
        width='60%'
        title='人员选择器'
        visible={visible}
        bodyStyle={{ height: '600px' }}
        onCancel={() => setVisible(false)}
        onOk={onOk}
        getContainer={false}
      >
        <div className={styles.box}>
          <div className={styles.left}>
            <div className={styles.title}>部门列表</div>
            <div className={styles.tree}>
              <Tree
                value={treeKey}
                fieldNames={{ title: 'ouName', key: 'ouCode' }}
                showIcon
                defaultExpandAll
                defaultSelectedKeys={['0-0-0']}
                switcherIcon={<DownOutlined />}
                treeData={treeData}
                onSelect={treeChange}
              />
            </div>
          </div>
          <div className={styles.right}>
            <div className={styles.title}>
              <Input.Search placeholder='请输入姓名进行查找' style={{ width: '300px' }} />
            </div>
            <div className={styles.list}>
              <div className={styles.userList}>
                <div className={styles.userStatus}>待选人员</div>
                <Table
                  rowKey={r => r[property]}
                  size='small'
                  columns={columns}
                  dataSource={userList}
                  pagination={false}
                  bordered
                  rowSelection={{
                    type: 'checkbox',
                    selectedRowKeys: selectKeys,
                    onChange: (select) => {
                      console.log('select', select)
                      let array = value ? value.split(',') : []
                      let users = array.concat(select)
                      onChange(users.join(','))
                    }
                  }}
                  scroll={{ y: 180 }}
                />
              </div>
              <div className={styles.selectList}>
                <div className={styles.userStatus}>已选人员</div>
                <Table
                  rowKey={r => r[property]}
                  rowSelection={{
                    type: 'checkbox',
                    selectedRowKeys: selectKeys,
                    onChange: (select) => {
                      onChange(select.join(','))
                    }
                  }}
                  size='small'
                  columns={columns}
                  dataSource={selectUser}
                  pagination={false}
                  bordered
                  scroll={{ y: 180 }}
                />
              </div>
            </div>
          </div>
        </div>
      </Modal>
    </div>
  )

}

export default UserTree